﻿local RPS_Version = "0.1 Beta"
local WoWversion = 60100
RPSDEV = 0 -- Developer tag, turn this on and you will be filled with logs!
RPSMACROIDERROR = nil --- If anything is wrong with a Macro, enable debuging by filling in MacroID
RPS = LibStub("AceAddon-3.0"):NewAddon("Profiles: Recount", "AceConsole-3.0", "AceEvent-3.0","AceTimer-3.0")
local AceGUI = LibStub("AceGUI-3.0")


function RPS:OnInitialize()
	RPSdb = LibStub("AceDB-3.0"):New("ProfilesRecount",nil,"Default")
	RPSglobaldb = LibStub("AceDB-3.0"):New("ProfilesRecountG",nil,"Default")
	RPS:SetupOptions()
		
	-- Different WoW version!
	if select(4, GetBuildInfo()) ~= WoWversion then
		RPS:UnregisterEvent("PVP_REWARDS_UPDATE")
		RPS:Echo("This addon is not compatible with this version of WoW. Please update it from curse.com")
	end
end
	
-- ProfilesHub: Send message to all slaves that we are now exporting profile
function RPS:PreExport(name)
	RPS:SendAceMsg("export",name) -- ProfilesHub
end

-- This is an alias for ProfilesHub
function RPS:Export(...)
	RPS:ExportCharProfile(...)
end

-- Export char profile to global
function RPS:ExportCharProfile(name)
	if RPS:ExistsProfile(name) then		
		local orig_profile = RPSdb:GetCurrentProfile()
		
		RPSglobaldb:SetProfile("General: "..name)
		RPSdb:SetProfile(name)
		
		-- RPSglobaldb.profile = RPSdb.profile
		for index, value in orderedPairs(RPSdb.profile) do
		  RPSglobaldb.profile[index] = value
		end
	
		RPSdb:SetProfile(orig_profile)
		
		return 1
	else
		RPS:Echo("No such profile exists: "..name)
		return nil
	end
end

function RPS:Echo(text)
	if PROFILES_TYST then return nil end
   DEFAULT_CHAT_FRAME:AddMessage("|c000000FFProfiles: Recount - "..text)
   return 1
end

-- ProfilesHub: Send message to all slaves that we are now saving profile
function RPS:PreSaveRecountProfile(name)
	RPS:SendAceMsg("save",name) -- ProfilesHub
end

-- This function should NOT BE CALLED DIRECTLY.
-- Should only be called by slave event!

function RPS:SaveRecountProfile(name)
   
   -- Global DB Code
   local DB = {}
   if string.find(name,"General:") then 
      DB = RPSglobaldb 
   else 
      DB = RPSdb 
   end
   
   DB:SetProfile(name)
   
   -- Solving /rps save tank X 2
   if RPS:ExistsProfile(name) then DB:ResetProfile(name) end
   
   RPS:Echo("Saving Recount settings to profile "..name.."!")
   
   -- DEV: print(inspect(Recount.db.profile["MainWindow"]["Position"]))
   
   
   -- Save the settings to db
   DB.profile["MainWindow"] = copyTable(Recount.db.profile["MainWindow"])
   DB.profile["MainWindowMode"] = copyTable(Recount.db.profile["MainWindowMode"])
   DB.profile["RealtimeWindows"] = copyTable(Recount.db.profile["RealtimeWindows"])
   
   RPS:SendMessage("RPS_Profiles_save",name) -- ProfilesHub
   return name
end


-- This is an alias for ProfilesHub
function RPS:Save(...)
	RPS:SaveRecountProfile(...)
end


-- ProfilesHub: Send message to all slaves that we are now loading profile
function RPS:PreLoadRecountProfile(name)
	RPS:SendAceMsg("load",name) -- ProfilesHub
end

-- This function should NOT BE CALLED DIRECTLY.
-- Should only be called by slave event!

function RPS:LoadRecountProfile(name)
   
   
   -- Global DB Code
   local DB = {}
   if string.find(name,"General:") then 
      DB = RPSglobaldb 
   else 
      DB = RPSdb 
   end
   
   -- No such profile saved
   if not RPS:ExistsProfile(name) then RPS:Echo("No such profile") return nil end
   
   -- In combat! 
   if InCombatLockdown() then RPS:Echo("Cannot change settings in combat!") return nil end
   
   DB:SetProfile(name)
   RPSdb.char.Active_profile = name
   
   RPS:Echo("Loading Recount settings from profile "..name.."!")
   
   -- Load
   
   Recount.db.profile["MainWindow"] = copyTable(DB.profile["MainWindow"])
   Recount:SetMainWindowMode(DB.profile.MainWindowMode)
   
   Recount_MainWindow:ClearAllPoints()
   Recount_MainWindow:SetPoint("CENTER",DB.profile.MainWindow.Position.x,DB.profile.MainWindow.Position.y)
   Recount_MainWindow:SetWidth(DB.profile.MainWindow.Position.w)
   Recount_MainWindow:SetHeight(DB.profile.MainWindow.Position.h)
   
   Recount:ResizeMainWindow()
   Recount:FullRefreshMainWindow()
   
   
   RPS:SendMessage("RPS_Profiles_load",name) -- ProfilesHub
   return name
end


-- This is an alias for ProfilesHub
function RPS:Load(...)
	RPS:LoadRecountProfile(...)
end

function RPS:ExistsProfile(name)
	-- Global DB Code
	local DB = {}
    if string.find(name,"General:") then
		DB = RPSglobaldb 
	else 
		DB = RPSdb 
	end
	
    for i, key in ipairs(DB:GetProfiles()) do
      if key == name then
         return (key)
      end
    end
   
    return nil
end

function RPS:ListProfiles(silent, globaldb)
    
    
	-- Global DB Code
	local DB = {}
    if globaldb then 	DB = RPSglobaldb 
	else 				DB = RPSdb 			end
	
	local RPS_profiles = {}
	
	for i,k in ipairs(DB:GetProfiles()) do
		if not silent then 
			RPS:Echo(" Available Profiles: ") 
			RPS:Echo(' - ' .. k) 
		end
		
		RP_profiles[k] = 0
	end

	
	return RPS_profiles
end

-- ProfilesHub: Send message to all slaves that we are now deleting a profile
function RPS:PreDeleteProfile(name)
	RPS:SendAceMsg("delete",name)
end

function RPS:DeleteProfil(name)

	-- Global DB Code
	local DB = {}
    if string.find(name,"General:") then 
		DB = RPSglobaldb 
	else 
		DB = RPSdb 
	end
	
	if (RPS:ExistsProfile(name)==nil)then
		RPS:Echo(name.." doesnt exist.")
		RPS:ListProfiles()
		
		return nil
	else
		if name == DB:GetCurrentProfile() then
			DB:SetProfile('Default')
		end
		DB:DeleteProfile(name)
		RPS:Echo(name.." deleted.")
		
		return name
	end
end

-- This is an alias for ProfilesHub
function RPS:Delete(...)
	RPS:DeleteProfil(...)
end